@@ -4,6 +4,7 @@ from __future__ import annotations
 import asyncio
 import datetime
 import urllib.parse
+from collections.abc import Mapping
 from json import JSONDecodeError
 from types import TracebackType
 from typing import Any, cast
@@ -70,11 +71,11 @@ from pyoverkiz.obfuscate import obfuscate_sensitive_data
 from pyoverkiz.types import JSON
 
 
-async def relogin(invocation: dict[str, Any]) -> None:
+async def relogin(invocation: Mapping[str, Any]) -> None:
     await invocation["args"][0].login()
 
 
-async def refresh_listener(invocation: dict[str, Any]) -> None:
+async def refresh_listener(invocation: Mapping[str, Any]) -> None:
     await invocation["args"][0].register_event_listener()
 
 
@@ -610,7 +611,10 @@ class OverkizClient:
         return response
 
     @backoff.on_exception(
-        backoff.expo, NotAuthenticatedException, max_tries=2, on_backoff=relogin
+        backoff.expo,
+        (NotAuthenticatedException, ServerDisconnectedError),
+        max_tries=2,
+        on_backoff=relogin,
     )
     async def cancel_command(self, exec_id: str) -> None:
         """Cancel a running setup-level execution"""
@@ -732,6 +736,17 @@ class OverkizClient:
         response = await self.__post(f"exec/{oid}")
         return cast(str, response["execId"])
 
+    @backoff.on_exception(
+        backoff.expo,
+        (NotAuthenticatedException, ServerDisconnectedError),
+        max_tries=2,
+        on_backoff=relogin,
+    )
+    async def execute_scheduled_scenario(self, oid: str, timestamp: int) -> str:
+        """Execute a scheduled scenario"""
+        response = await self.__post(f"exec/schedule/{oid}/{timestamp}")
+        return cast(str, response["triggerId"])
+
     async def __get(self, path: str) -> Any:
         """Make a GET request to the OverKiz API"""
         headers = {}
