@@ -10,6 +10,9 @@ class OverkizAttribute(str, Enum):
     CORE_MAX_SETTABLE_VALUE = "core:MaxSettableValue"
     CORE_MEASURED_VALUE_TYPE = "core:MeasuredValueType"
     CORE_MIN_SETTABLE_VALUE = "core:MinSettableValue"
+    CORE_ELECTRIC_POWER_CONSUMPTION_STATE_MEASURED_VALUE_TYPE = (
+        "core:ElectricPowerConsumptionStateMeasuredValueType"
+    )
     HOMEKIT_SETUP_CODE = "homekit:SetupCode"
 
 
@@ -117,6 +120,7 @@ class OverkizState(str, Enum):
     CORE_TARGET_DWH_TEMPERATURE = "core:TargetDHWTemperatureState"
     CORE_TARGET_TEMPERATURE = "core:TargetTemperatureState"
     CORE_TEMPERATURE = "core:TemperatureState"
+    CORE_THERMAL_CONFIGURATION = "core:ThermalConfigurationState"
     CORE_THERMAL_ENERGY_CONSUMPTION = "core:ThermalEnergyConsumptionState"
     CORE_THREE_WAY_HANDLE_DIRECTION = "core:ThreeWayHandleDirectionState"
     CORE_V40_WATER_VOLUME_ESTIMATION = "core:V40WaterVolumeEstimationState"
