@@ -82,7 +82,7 @@ class Location:
     latitude: str = field(repr=obfuscate_string, default=None)
     twilight_mode: int
     twilight_angle: str
-    twilight_city: str
+    twilight_city: str | None = None
     summer_solstice_dusk_minutes: str
     winter_solstice_dusk_minutes: str
     twilight_offset_enabled: bool
@@ -104,7 +104,7 @@ class Location:
         latitude: str = field(repr=obfuscate_string, default=None),
         twilight_mode: int,
         twilight_angle: str,
-        twilight_city: str,
+        twilight_city: str | None = None,
         summer_solstice_dusk_minutes: str,
         winter_solstice_dusk_minutes: str,
         twilight_offset_enabled: bool,
@@ -634,7 +634,7 @@ class HistoryExecution:
     owner: str = field(repr=obfuscate_email)
     source: str
     end_time: int
-    effective_start_time: int
+    effective_start_time: int | None = None
     duration: int
     label: str | None = None
     type: str
@@ -652,7 +652,7 @@ class HistoryExecution:
         owner: str,
         source: str,
         end_time: int,
-        effective_start_time: int,
+        effective_start_time: int | None = None,
         duration: int,
         label: str | None = None,
         type: str,
